# Field and Efficiency Metrics

## Field Metrics
::: fdtdx.core.physics.metrics.compute_energy
::: fdtdx.core.physics.metrics.normalize_by_energy
::: fdtdx.core.physics.metrics.poynting_flux

## Efficiency Metrics
::: fdtdx.core.physics.losses.metric_efficiency
